@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from OFS.SimpleItem import SimpleItem
 from plone.schemaeditor.browser.field.traversal import FieldContext
 from plone.schemaeditor.interfaces import ISchemaContext
@@ -6,14 +5,12 @@ from zope.interface import implementer
 from zope.publisher.interfaces.browser import IBrowserPublisher
 from ZPublisher.BaseRequest import DefaultPublishTraverse
 
-import six
-
 
 @implementer(ISchemaContext, IBrowserPublisher)
 class SchemaContext(SimpleItem):
 
-    """ This is a transient item that allows us to traverse through (a wrapper
-        of) a zope 3 schema to (a wrapper of) a zope 3 schema field.
+    """This is a transient item that allows us to traverse through (a wrapper
+    of) a zope 3 schema to (a wrapper of) a zope 3 schema field.
     """
 
     schemaEditorView = None
@@ -22,7 +19,7 @@ class SchemaContext(SimpleItem):
     fieldsWhichCannotBeDeleted = ()
     enableFieldsets = True
 
-    def __init__(self, context, request, name=u'schema', title=None):
+    def __init__(self, context, request, name="schema", title=None):
         self.schema = context
         self.request = request
 
@@ -34,19 +31,16 @@ class SchemaContext(SimpleItem):
         self.Title = lambda: title
 
     def publishTraverse(self, request, name):
-        """ Look up the field whose name matches the next URL path element,
+        """Look up the field whose name matches the next URL path element,
         and wrap it.
         """
         try:
             return FieldContext(self.schema[name], self.request).__of__(self)
         except KeyError:
-            return DefaultPublishTraverse(self, request).publishTraverse(
-                request,
-                name
-            )
+            return DefaultPublishTraverse(self, request).publishTraverse(request, name)
 
     def browserDefault(self, request):
-        """ If not traversing through the schema to a field,
+        """If not traversing through the schema to a field,
         show the SchemaListingPage.
         """
-        return self, ('@@edit',)
+        return self, ("@@edit",)
